.. _l-doctestunit:

Documentation, unit tests, setup
================================

See `Unit tests with pyquickhelper <http://www.xavierdupre.fr/app/pyquickhelper/helpsphinx/doctestunit.html>`_.

Extensions to install
+++++++++++++++++++++

* `pyquickhelper <https://pypi.python.org/pypi/pyquickhelper/>`_
